@@ -36,7 +36,8 @@ export const descendant = new ExternalTokenizer(input => {
   if (space.includes(input.peek(-1))) {
     let {next} = input
     if (isAlpha(next) || next == underscore || next == hash || next == period ||
-        next == bracketL || next == colon || next == dash || next == ampersand)
+        next == bracketL || next == colon && isAlpha(input.peek(1)) ||
+        next == dash || next == ampersand)
       input.acceptToken(descendantOp)
   }
 })
@@ -46,7 +47,7 @@ export const unitToken = new ExternalTokenizer(input => {
     let {next} = input
     if (next == percent) { input.advance(); input.acceptToken(Unit) }
     if (isAlpha(next)) {
-      do { input.advance() } while (isAlpha(input.next))
+      do { input.advance() } while (isAlpha(input.next) || isDigit(input.next))
       input.acceptToken(Unit)
     }
   }
